Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(409)

Unified Diff: pkg/analyzer/lib/src/summary/resynthesize.dart

Issue 1695033002: Ignore enclosing class type parameters in resynthesizing static class members. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/analyzer/test/src/summary/resynthesize_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/summary/resynthesize.dart
diff --git a/pkg/analyzer/lib/src/summary/resynthesize.dart b/pkg/analyzer/lib/src/summary/resynthesize.dart
index b93821b6953351c7f8f05b6d8a445404435ddd16..ab28202d821488d62b27f4d830c0e5aa2a24c3cc 100644
--- a/pkg/analyzer/lib/src/summary/resynthesize.dart
+++ b/pkg/analyzer/lib/src/summary/resynthesize.dart
@@ -850,7 +850,13 @@ class _LibraryResynthesizer {
case UnlinkedExecutableKind.functionOrMethod:
case UnlinkedExecutableKind.getter:
case UnlinkedExecutableKind.setter:
+ if (serializedExecutable.isStatic) {
+ currentTypeParameters.removeLast();
+ }
buildExecutable(serializedExecutable, memberHolder);
+ if (serializedExecutable.isStatic) {
+ currentTypeParameters.add(classElement.typeParameters);
+ }
break;
}
}
@@ -1647,7 +1653,7 @@ class _LibraryResynthesizer {
}
/**
* Build [TypeParameterElements] corresponding to the type parameters in
* [serializedTypeParameters] and store them in [currentTypeParameters].
* Also return them.
*/
@@ -1647,7 +1653,7 @@ class _LibraryResynthesizer {
}
/**
- * Build [TypeParameterElements] corresponding to the type parameters in
+ * Build [TypeParameterElement]s corresponding to the type parameters in
* [serializedTypeParameters] and store them in [currentTypeParameters].
* Also return them.
« no previous file with comments | « no previous file | pkg/analyzer/test/src/summary/resynthesize_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698